@@ -7,7 +7,7 @@ This module provides some basic information about the package.
 """
 
 # Set the package release version
-version_info = (0, 0, 1)
+version_info = (0, 0, 3)
 __version__ = '.'.join(str(c) for c in version_info)
 
 # Set the package details
@@ -15,11 +15,11 @@ __author__ = 'Tobias Liaudat'
 __email__ = 'tobiasliaudat@gmail.com'
 __year__ = '2020'
 __url__ = 'https://github.com/CosmoStat/mccd'
-__description__ = 'A non-parametric Multi-CCD Point Spread Function modelling'
+__description__ = 'A non-parametric Multi-CCD Point Spread Function modelling.'
 
 # Default package properties
 __license__ = 'MIT'
-__about__ = ('{} \n\n Author: {} \n Email: {} \n Year: {} \n {} \n\n'
+__about__ = ('{}\nAuthor: {} \nEmail: {} \nYear: {} \nInfo: {}'
              ''.format(__name__, __author__, __email__, __year__,
                        __description__))
 __setup_requires__ = ['pytest-runner', ]
