@@ -289,7 +289,7 @@ class MccdInputs(object):
 
         """
         # Remove the .fits or the extension
-        my_path = path.split('.')[0]
+        my_path = path.split('.')[-2]
 
         # split the path to get the info
         splitted_str = my_path.split(self.separator)
@@ -550,6 +550,10 @@ class MccdInputs(object):
         # Return the inputs
         return self.prep_mccd_inputs(self.starcat_list[idx])
 
+    def get_catalog_ids(self):
+        r"""Get preprocessed catalog ids."""
+        return self.catalog_ids
+
     @staticmethod
     def outlier_rejection(star_list, pos_list, mask_list, ccd_list,
                           SNR_list=None, RA_list=None, DEC_list=None,
